@@ -1,4 +1,4 @@
-# IUP::Plot example
+# IUP::PPlot example
 
 use strict;
 use warnings;
@@ -13,22 +13,22 @@ sub create_pplot {
   $args{AXS_YAUTOMAX} = "NO" if defined $args{AXS_YMAX};
   $args{AXS_XAUTOMIN} = "NO" if defined $args{AXS_XMIN};
   $args{AXS_XAUTOMAX} = "NO" if defined $args{AXS_XMAX};
-  return IUP::Plot->new(%args);  
+  return IUP::PPlot->new(%args);  
 }
 
 sub add_series {
   my ($plot, $xvalues, $yvalues, $options) = @_;
   # are we given strings for the x values?
-  $plot->PlotBegin(looks_like_number($xvalues->[1]) ? 0 : 1);
-  $plot->PlotAdd($xvalues->[$_],$yvalues->[$_]) for (0..scalar(@$xvalues)-1);
-  $plot->PlotEnd();
+  if (looks_like_number($xvalues->[1])) {
+    $plot->PlotAdd2D($xvalues,$yvalues);
+  }
+  else {
+    $plot->PlotAdd1D($xvalues,$yvalues);
+  }
   # set any series-specific plot attributes
   if ($options) {
     # mode must be set before any other attributes!
-    if ($options->{DS_MODE}) {
-      $plot->DS_MODE($options->{DS_MODE});
-      delete $options->{DS_MODE};
-    }
+    $plot->DS_MODE(delete $options->{DS_MODE}) if $options->{DS_MODE};
     $plot->SetAttribute(%$options);
   }
 }
